@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -14,7 +14,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
 /**
- * Constains the dictionary of language entries.
+ * Contains the dictionary of language entries.
  * @namespace
  */
 CKEDITOR.lang['hr'] =
@@ -31,11 +31,12 @@ CKEDITOR.lang['hr'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'Bogati uređivač teksta, %1',
+	editorHelp : 'Pritisni ALT 0 za pomoć',
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Alatne trake uređivača teksta',
+	editor		: 'Bogati uređivač teksta',
 
 	// Toolbar buttons without dialogs.
 	source			: 'Kôd',
@@ -56,6 +57,7 @@ CKEDITOR.lang['hr'] =
 	superscript		: 'Superscript',
 	horizontalrule	: 'Ubaci vodoravnu liniju',
 	pagebreak		: 'Ubaci prijelom stranice',
+	pagebreakAlt		: 'Prijelom stranice',
 	unlink			: 'Ukloni link',
 	undo			: 'Poništi',
 	redo			: 'Ponovi',
@@ -92,35 +94,62 @@ CKEDITOR.lang['hr'] =
 		cssStyle		: 'Stil',
 		ok				: 'OK',
 		cancel			: 'Poništi',
-		close			: 'Close', // MISSING
-		preview			: 'Preview', // MISSING
+		close			: 'Zatvori',
+		preview			: 'Pregledaj',
 		generalTab		: 'Općenito',
 		advancedTab		: 'Napredno',
 		validateNumberFailed : 'Ova vrijednost nije broj.',
 		confirmNewPage	: 'Sve napravljene promjene će biti izgubljene ukoliko ih niste snimili. Sigurno želite učitati novu stranicu?',
 		confirmCancel	: 'Neke od opcija su promjenjene. Sigurno želite zatvoriti ovaj prozor?',
-		options			: 'Options', // MISSING
-		target			: 'Target', // MISSING
-		targetNew		: 'New Window (_blank)', // MISSING
-		targetTop		: 'Topmost Window (_top)', // MISSING
-		targetSelf		: 'Same Window (_self)', // MISSING
-		targetParent	: 'Parent Window (_parent)', // MISSING
+		options			: 'Opcije',
+		target			: 'Odredište',
+		targetNew		: 'Novi prozor (_blank)',
+		targetTop		: 'Vršni prozor (_top)',
+		targetSelf		: 'Isti prozor (_self)',
+		targetParent	: 'Roditeljski prozor (_parent)',
+		langDirLTR		: 'S lijeva na desno (LTR)',
+		langDirRTL		: 'S desna na lijevo (RTL)',
+		styles			: 'Stil',
+		cssClasses		: 'Klase stilova',
+		width			: 'Širina',
+		height			: 'Visina',
+		align			: 'Poravnaj',
+		alignLeft		: 'Lijevo',
+		alignRight		: 'Desno',
+		alignCenter		: 'Središnje',
+		alignTop		: 'Vrh',
+		alignMiddle		: 'Sredina',
+		alignBottom		: 'Dolje',
+		invalidValue	: 'Invalid value.', // MISSING
+		invalidHeight	: 'Visina mora biti broj.',
+		invalidWidth	: 'Širina mora biti broj.',
+		invalidCssLength	: 'Vrijednost određena za "%1" polje mora biti pozitivni broj sa ili bez važećih CSS mjernih jedinica (px, %, in, cm, mm, em, ex, pt ili pc).',
+		invalidHtmlLength	: 'Vrijednost određena za "%1" polje mora biti pozitivni broj sa ili bez važećih HTML mjernih jedinica (px ili %).',
+		invalidInlineStyle	: 'Vrijednost za linijski stil mora sadržavati jednu ili više definicija s formatom "naziv:vrijednost", odvojenih točka-zarezom.',
+		cssLengthTooltip	: 'Unesite broj za vrijednost u pikselima ili broj s važećim CSS mjernim jedinicama (px, %, in, cm, mm, em, ex, pt ili pc).',
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, nedostupno</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'Opcije izbornika'
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Ubaci posebne znakove',
-		title		: 'Odaberite posebni karakter'
+		title		: 'Odaberite posebni karakter',
+		options : 'Opcije specijalnih znakova'
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Ubaci/promijeni link',
+		other 		: '<drugi>',
 		menu		: 'Promijeni link',
 		title		: 'Link',
 		info		: 'Link Info',
@@ -128,7 +157,7 @@ CKEDITOR.lang['hr'] =
 		upload		: 'Pošalji',
 		advanced	: 'Napredno',
 		type		: 'Link vrsta',
-		toUrl		: 'URL', // MISSING
+		toUrl		: 'URL',
 		toAnchor	: 'Sidro na ovoj stranici',
 		toEmail		: 'E-Mail',
 		targetFrame		: '<okvir>',
@@ -144,9 +173,7 @@ CKEDITOR.lang['hr'] =
 		popupFullScreen	: 'Cijeli ekran (IE)',
 		popupScrollBars	: 'Scroll traka',
 		popupDependent	: 'Ovisno (Netscape)',
-		popupWidth		: 'Širina',
 		popupLeft		: 'Lijeva pozicija',
-		popupHeight		: 'Visina',
 		popupTop		: 'Gornja pozicija',
 		id				: 'Id',
 		langDir			: 'Smjer jezika',
@@ -154,18 +181,19 @@ CKEDITOR.lang['hr'] =
 		langDirRTL		: 'S desna na lijevo (RTL)',
 		acccessKey		: 'Pristupna tipka',
 		name			: 'Naziv',
-		langCode		: 'Smjer jezika',
-		tabIndex		: 'Tab Indeks',
-		advisoryTitle	: 'Advisory naslov',
+		langCode			: 'Smjer jezika',
+		tabIndex			: 'Tab Indeks',
+		advisoryTitle		: 'Advisory naslov',
 		advisoryContentType	: 'Advisory vrsta sadržaja',
 		cssClasses		: 'Stylesheet klase',
 		charset			: 'Kodna stranica povezanih resursa',
 		styles			: 'Stil',
-		selectAnchor	: 'Odaberi sidro',
+		rel			: 'Veza',
+		selectAnchor		: 'Odaberi sidro',
 		anchorName		: 'Po nazivu sidra',
-		anchorId		: 'Po Id elementa',
-		emailAddress	: 'E-Mail adresa',
-		emailSubject	: 'Naslov',
+		anchorId			: 'Po Id elementa',
+		emailAddress		: 'E-Mail adresa',
+		emailSubject		: 'Naslov',
 		emailBody		: 'Sadržaj poruke',
 		noAnchors		: '(Nema dostupnih sidra)',
 		noUrl			: 'Molimo upišite URL link',
@@ -179,7 +207,32 @@ CKEDITOR.lang['hr'] =
 		menu		: 'Svojstva sidra',
 		title		: 'Svojstva sidra',
 		name		: 'Ime sidra',
-		errorName	: 'Molimo unesite ime sidra'
+		errorName	: 'Molimo unesite ime sidra',
+		remove		: 'Ukloni sidro'
+	},
+
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Svojstva brojčane liste',
+		bulletedTitle		: 'Svojstva liste',
+		type				: 'Vrsta',
+		start				: 'Početak',
+		validateStartNumber				:'Početak brojčane liste mora biti cijeli broj.',
+		circle				: 'Krug',
+		disc				: 'Disk',
+		square				: 'Kvadrat',
+		none				: 'Bez',
+		notset				: '<nije određen>',
+		armenian			: 'Armenijska numeracija',
+		georgian			: 'Gruzijska numeracija(an, ban, gan, etc.)',
+		lowerRoman			: 'Romanska numeracija mala slova (i, ii, iii, iv, v, itd.)',
+		upperRoman			: 'Romanska numeracija velika slova (I, II, III, IV, V, itd.)',
+		lowerAlpha			: 'Znakovi mala slova (a, b, c, d, e, itd.)',
+		upperAlpha			: 'Znakovi velika slova (A, B, C, D, E, itd.)',
+		lowerGreek			: 'Grčka numeracija mala slova (alfa, beta, gama, itd).',
+		decimal				: 'Decimalna numeracija (1, 2, 3, itd.)',
+		decimalLeadingZero	: 'Decimalna s vodećom nulom (01, 02, 03, itd)'
 	},
 
 	// Find And Replace Dialog
@@ -191,6 +244,7 @@ CKEDITOR.lang['hr'] =
 		findWhat			: 'Pronađi:',
 		replaceWith			: 'Zamijeni s:',
 		notFoundMsg			: 'Traženi tekst nije pronađen.',
+		findOptions			: 'Opcije traženja',
 		matchCase			: 'Usporedi mala/velika slova',
 		matchWord			: 'Usporedi cijele riječi',
 		matchCyclic			: 'Usporedi kružno',
@@ -208,15 +262,9 @@ CKEDITOR.lang['hr'] =
 		rows		: 'Redova',
 		columns		: 'Kolona',
 		border		: 'Veličina okvira',
-		align		: 'Poravnanje',
-		alignLeft	: 'Lijevo',
-		alignCenter	: 'Središnje',
-		alignRight	: 'Desno',
-		width		: 'Širina',
 		widthPx		: 'piksela',
 		widthPc		: 'postotaka',
-		widthUnit	: 'width unit', // MISSING
-		height		: 'Visina',
+		widthUnit	: 'jedinica širine',
 		cellSpace	: 'Prostornost ćelija',
 		cellPad		: 'Razmak ćelija',
 		caption		: 'Naslov',
@@ -252,9 +300,6 @@ CKEDITOR.lang['hr'] =
 			wordWrap		: 'Prelazak u novi red',
 			hAlign			: 'Vodoravno poravnanje',
 			vAlign			: 'Okomito poravnanje',
-			alignTop		: 'Vrh',
-			alignMiddle		: 'Sredina',
-			alignBottom		: 'Dolje',
 			alignBaseline	: 'Osnovna linija',
 			bgColor			: 'Boja pozadine',
 			borderColor		: 'Boja ruba',
@@ -266,7 +311,7 @@ CKEDITOR.lang['hr'] =
 			invalidHeight	: 'Visina ćelije mora biti broj.',
 			invalidRowSpan	: 'Rows span mora biti cijeli broj.',
 			invalidColSpan	: 'Columns span mora biti cijeli broj.',
-			chooseColor		: 'Choose' // MISSING
+			chooseColor		: 'Odaberi'
 		},
 
 		row :
@@ -375,27 +420,19 @@ CKEDITOR.lang['hr'] =
 		btnUpload	: 'Pošalji na server',
 		upload		: 'Pošalji',
 		alt			: 'Alternativni tekst',
-		width		: 'Širina',
-		height		: 'Visina',
 		lockRatio	: 'Zaključaj odnos',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Obriši veličinu',
 		border		: 'Okvir',
 		hSpace		: 'HSpace',
 		vSpace		: 'VSpace',
-		align		: 'Poravnaj',
-		alignLeft	: 'Lijevo',
-		alignRight	: 'Desno',
 		alertUrl	: 'Unesite URL slike',
 		linkTab		: 'Link',
 		button2Img	: 'Želite li promijeniti odabrani gumb u jednostavnu sliku?',
 		img2Button	: 'Želite li promijeniti odabranu sliku u gumb?',
-		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
-		validateBorder	: 'Border must be a whole number.', // MISSING
-		validateHSpace	: 'HSpace must be a whole number.', // MISSING
-		validateVSpace	: 'VSpace must be a whole number.' // MISSING
+		urlMissing	: 'Nedostaje URL slike.',
+		validateBorder	: 'Okvir mora biti cijeli broj.',
+		validateHSpace	: 'HSpace mora biti cijeli broj',
+		validateVSpace	: 'VSpace mora biti cijeli broj.'
 	},
 
 	// Flash Dialog
@@ -416,16 +453,10 @@ CKEDITOR.lang['hr'] =
 		accessAlways	: 'Uvijek',
 		accessSameDomain: 'Ista domena',
 		accessNever		: 'Nikad',
-		align			: 'Poravnaj',
-		alignLeft		: 'Lijevo',
 		alignAbsBottom	: 'Abs dolje',
 		alignAbsMiddle	: 'Abs sredina',
 		alignBaseline	: 'Bazno',
-		alignBottom		: 'Dolje',
-		alignMiddle		: 'Sredina',
-		alignRight		: 'Desno',
 		alignTextTop	: 'Vrh teksta',
-		alignTop		: 'Vrh',
 		quality			: 'Kvaliteta',
 		qualityBest		: 'Best',
 		qualityHigh		: 'High',
@@ -439,13 +470,9 @@ CKEDITOR.lang['hr'] =
 		windowMode		: 'Vrsta prozora',
 		flashvars		: 'Varijable za Flash',
 		bgcolor			: 'Boja pozadine',
-		width			: 'Širina',
-		height			: 'Visina',
 		hSpace			: 'HSpace',
 		vSpace			: 'VSpace',
 		validateSrc		: 'Molimo upišite URL link',
-		validateWidth	: 'Širina mora biti broj.',
-		validateHeight	: 'Visina mora biti broj.',
 		validateHSpace	: 'HSpace mora biti broj.',
 		validateVSpace	: 'VSpace mora biti broj.'
 	},
@@ -476,12 +503,13 @@ CKEDITOR.lang['hr'] =
 	smiley :
 	{
 		toolbar	: 'Smješko',
-		title	: 'Ubaci smješka'
+		title	: 'Ubaci smješka',
+		options : 'Opcije smješka'
 	},
 
 	elementsPath :
 	{
-		eleLabel : 'Elements path', // MISSING
+		eleLabel : 'Putanja elemenata',
 		eleTitle : '%1 element'
 	},
 
@@ -503,11 +531,11 @@ CKEDITOR.lang['hr'] =
 	clipboard :
 	{
 		title		: 'Zalijepi',
-		cutError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog izrezivanja. Molimo koristite kraticu na tipkovnici (Ctrl+X).',
-		copyError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog kopiranja. Molimo koristite kraticu na tipkovnici (Ctrl+C).',
-		pasteMsg	: 'Molimo zaljepite unutar doljnjeg okvira koristeći tipkovnicu (<STRONG>Ctrl+V</STRONG>) i kliknite <STRONG>OK</STRONG>.',
+		cutError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog izrezivanja. Molimo koristite kraticu na tipkovnici (Ctrl/Cmd+X).',
+		copyError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog kopiranja. Molimo koristite kraticu na tipkovnici (Ctrl/Cmd+C).',
+		pasteMsg	: 'Molimo zaljepite unutar doljnjeg okvira koristeći tipkovnicu (<STRONG>Ctrl/Cmd+V</STRONG>) i kliknite <STRONG>OK</STRONG>.',
 		securityMsg	: 'Zbog sigurnosnih postavki Vašeg pretraživača, editor nema direktan pristup Vašem međuspremniku. Potrebno je ponovno zalijepiti tekst u ovaj prozor.',
-		pasteArea	: 'Paste Area' // MISSING
+		pasteArea	: 'Prostor za ljepljenje'
 	},
 
 	pastefromword :
@@ -515,7 +543,7 @@ CKEDITOR.lang['hr'] =
 		confirmCleanup	: 'Tekst koji želite zalijepiti čini se da je kopiran iz Worda. Želite li prije očistiti tekst?',
 		toolbar			: 'Zalijepi iz Worda',
 		title			: 'Zalijepi iz Worda',
-		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		error			: 'Nije moguće očistiti podatke za ljepljenje zbog interne greške'
 	},
 
 	pasteText :
@@ -528,6 +556,7 @@ CKEDITOR.lang['hr'] =
 	{
 		button			: 'Predlošci',
 		title			: 'Predlošci sadržaja',
+		options : 'Opcije predložaka',
 		insertOption	: 'Zamijeni trenutne sadržaje',
 		selectPromptMsg	: 'Molimo odaberite predložak koji želite otvoriti<br>(stvarni sadržaj će biti izgubljen):',
 		emptyListMsg	: '(Nema definiranih predložaka)'
@@ -538,7 +567,7 @@ CKEDITOR.lang['hr'] =
 	stylesCombo :
 	{
 		label		: 'Stil',
-		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle	: 'Stilovi formatiranja',
 		panelTitle1	: 'Block stilovi',
 		panelTitle2	: 'Inline stilovi',
 		panelTitle3	: 'Object stilovi'
@@ -563,21 +592,30 @@ CKEDITOR.lang['hr'] =
 
 	div :
 	{
-		title				: 'Create Div Container', // MISSING
-		toolbar				: 'Create Div Container', // MISSING
-		cssClassInputLabel	: 'Stylesheet Classes', // MISSING
-		styleSelectLabel	: 'Style', // MISSING
-		IdInputLabel		: 'Id', // MISSING
-		languageCodeInputLabel	: ' Language Code', // MISSING
-		inlineStyleInputLabel	: 'Inline Style', // MISSING
-		advisoryTitleInputLabel	: 'Advisory Title', // MISSING
-		langDirLabel		: 'Language Direction', // MISSING
-		langDirLTRLabel		: 'Left to Right (LTR)', // MISSING
-		langDirRTLLabel		: 'Right to Left (RTL)', // MISSING
-		edit				: 'Edit Div', // MISSING
-		remove				: 'Remove Div' // MISSING
+		title				: 'Napravi DIV kontejner',
+		toolbar				: 'Napravi DIV kontejner',
+		cssClassInputLabel	: 'Klase stilova',
+		styleSelectLabel	: 'Stil',
+		IdInputLabel		: 'Id',
+		languageCodeInputLabel	: 'Jezični kod',
+		inlineStyleInputLabel	: 'Stil u liniji',
+		advisoryTitleInputLabel	: 'Savjetodavni naslov',
+		langDirLabel		: 'Smjer jezika',
+		langDirLTRLabel		: 'S lijeva na desno (LTR)',
+		langDirRTLLabel		: 'S desna na lijevo (RTL)',
+		edit				: 'Uredi DIV',
+		remove				: 'Ukloni DIV'
   	},
 
+	iframe :
+	{
+		title		: 'IFrame svojstva',
+		toolbar		: 'IFrame',
+		noUrl		: 'Unesite URL iframe-a',
+		scrolling	: 'Omogući trake za skrolanje',
+		border		: 'Prikaži okvir IFrame-a'
+	},
+
 	font :
 	{
 		label		: 'Font',
@@ -596,58 +634,59 @@ CKEDITOR.lang['hr'] =
 	{
 		textColorTitle	: 'Boja teksta',
 		bgColorTitle	: 'Boja pozadine',
-		panelTitle		: 'Colors', // MISSING
+		panelTitle		: 'Boje',
 		auto			: 'Automatski',
 		more			: 'Više boja...'
 	},
 
 	colors :
 	{
-		'000' : 'Black', // MISSING
-		'800000' : 'Maroon', // MISSING
-		'8B4513' : 'Saddle Brown', // MISSING
-		'2F4F4F' : 'Dark Slate Gray', // MISSING
-		'008080' : 'Teal', // MISSING
-		'000080' : 'Navy', // MISSING
-		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
-		'B22222' : 'Fire Brick', // MISSING
-		'A52A2A' : 'Brown', // MISSING
-		'DAA520' : 'Golden Rod', // MISSING
-		'006400' : 'Dark Green', // MISSING
-		'40E0D0' : 'Turquoise', // MISSING
-		'0000CD' : 'Medium Blue', // MISSING
-		'800080' : 'Purple', // MISSING
-		'808080' : 'Gray', // MISSING
-		'F00' : 'Red', // MISSING
-		'FF8C00' : 'Dark Orange', // MISSING
-		'FFD700' : 'Gold', // MISSING
-		'008000' : 'Green', // MISSING
-		'0FF' : 'Cyan', // MISSING
-		'00F' : 'Blue', // MISSING
-		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
-		'FFA07A' : 'Light Salmon', // MISSING
-		'FFA500' : 'Orange', // MISSING
-		'FFFF00' : 'Yellow', // MISSING
-		'00FF00' : 'Lime', // MISSING
-		'AFEEEE' : 'Pale Turquoise', // MISSING
-		'ADD8E6' : 'Light Blue', // MISSING
-		'DDA0DD' : 'Plum', // MISSING
-		'D3D3D3' : 'Light Grey', // MISSING
-		'FFF0F5' : 'Lavender Blush', // MISSING
-		'FAEBD7' : 'Antique White', // MISSING
-		'FFFFE0' : 'Light Yellow', // MISSING
-		'F0FFF0' : 'Honeydew', // MISSING
-		'F0FFFF' : 'Azure', // MISSING
-		'F0F8FF' : 'Alice Blue', // MISSING
-		'E6E6FA' : 'Lavender', // MISSING
-		'FFF' : 'White' // MISSING
+		'000' : 'Crna',
+		'800000' : 'Kesten',
+		'8B4513' : 'Smeđa',
+		'2F4F4F' : 'Tamno siva',
+		'008080' : 'Teal',
+		'000080' : 'Mornarska',
+		'4B0082' : 'Indigo',
+		'696969' : 'Tamno siva',
+		'B22222' : 'Vatrena cigla',
+		'A52A2A' : 'Smeđa',
+		'DAA520' : 'Zlatna',
+		'006400' : 'Tamno zelena',
+		'40E0D0' : 'Tirkizna',
+		'0000CD' : 'Srednje plava',
+		'800080' : 'Ljubičasta',
+		'808080' : 'Siva',
+		'F00' : 'Crvena',
+		'FF8C00' : 'Tamno naranđasta',
+		'FFD700' : 'Zlatna',
+		'008000' : 'Zelena',
+		'0FF' : 'Cijan',
+		'00F' : 'Plava',
+		'EE82EE' : 'Ljubičasta',
+		'A9A9A9' : 'Mutno siva',
+		'FFA07A' : 'Svijetli losos',
+		'FFA500' : 'Naranđasto',
+		'FFFF00' : 'Žuto',
+		'00FF00' : 'Limun',
+		'AFEEEE' : 'Blijedo tirkizna',
+		'ADD8E6' : 'Svijetlo plava',
+		'DDA0DD' : 'Šljiva',
+		'D3D3D3' : 'Svijetlo siva',
+		'FFF0F5' : 'Lavanda rumeno',
+		'FAEBD7' : 'Antikno bijela',
+		'FFFFE0' : 'Svijetlo žuta',
+		'F0FFF0' : 'Med',
+		'F0FFFF' : 'Azurna',
+		'F0F8FF' : 'Alice plava',
+		'E6E6FA' : 'Lavanda',
+		'FFF' : 'Bijela'
 	},
 
 	scayt :
 	{
 		title			: 'Provjeri pravopis tijekom tipkanja (SCAYT)',
+		opera_title		: 'Nije podržano u Operi',
 		enable			: 'Omogući SCAYT',
 		disable			: 'Onemogući SCAYT',
 		about			: 'O SCAYT',
@@ -659,9 +698,23 @@ CKEDITOR.lang['hr'] =
 		ignoreAll		: 'Zanemari sve',
 		addWord			: 'Dodaj riječ',
 		emptyDic		: 'Naziv rječnika ne smije biti prazno.',
+		noSuggestions	: 'Nema preporuke',
 		optionsTab		: 'Opcije',
+		allCaps			: 'Ignoriraj riječi s velikim slovima',
+		ignoreDomainNames : 'Ignoriraj nazive domena',
+		mixedCase		: 'Ignoriraj riječi s miješanim slovima',
+		mixedWithDigits	: 'Ignoriraj riječi s brojevima',
+
 		languagesTab	: 'Jezici',
+
 		dictionariesTab	: 'Rječnici',
+		dic_field_name	: 'Naziv riječnika',
+		dic_create		: 'Napravi',
+		dic_restore		: 'Povrati',
+		dic_delete		: 'Obriši',
+		dic_rename		: 'Promijeni naziv',
+		dic_info		: 'Na početku se korisnički Riječnik sprema u Cookie. Nažalost, veličina im je ograničena. Kada korisnički Riječnik naraste preko te veličine, Riječnik će biti smješten na naš server. Kako bi se korisnički Riječnik spremio na naš server morate odabrati naziv Vašeg Riječnika. Ukoliko ste već prije spremali Riječnik na naše servere, unesite naziv Riječnika i pritisnite na Povrati.',
+
 		aboutTab		: 'O SCAYT'
 	},
 
@@ -669,31 +722,96 @@ CKEDITOR.lang['hr'] =
 	{
 		title		: 'O CKEditoru',
 		dlgTitle	: 'O CKEditoru',
+		help	: 'Provjeri $1 za pomoć.',
+		userGuide : 'Vodič za CKEditor korisnike',
 		moreInfo	: 'Za informacije o licencama posjetite našu web stranicu:',
 		copy		: 'Copyright &copy; $1. All rights reserved.'
 	},
 
 	maximize : 'Povećaj',
-	minimize : 'Minimize', // MISSING
+	minimize : 'Smanji',
 
 	fakeobjects :
 	{
-		anchor	: 'Sidro',
-		flash	: 'Flash animacija',
-		div		: 'Prijelom stranice',
-		unknown	: 'Nepoznati objekt'
+		anchor		: 'Sidro',
+		flash		: 'Flash animacija',
+		iframe		: 'IFrame',
+		hiddenfield	: 'Sakriveno polje',
+		unknown		: 'Nepoznati objekt'
 	},
 
 	resize : 'Povuci za promjenu veličine',
 
 	colordialog :
 	{
-		title		: 'Select color', // MISSING
-		highlight	: 'Highlight', // MISSING
-		selected	: 'Selected', // MISSING
-		clear		: 'Clear' // MISSING
+		title		: 'Odaberi boju',
+		options	:	'Opcije boje',
+		highlight	: 'Istaknuto',
+		selected	: 'Odabrana boja',
+		clear		: 'Očisti'
 	},
 
-	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Smanji alatnu traku',
+	toolbarExpand	: 'Proširi alatnu traku',
+
+	toolbarGroups :
+	{
+		document : 'Dokument',
+		clipboard : 'Međuspremnik/Poništi',
+		editing : 'Uređivanje',
+		forms : 'Forme',
+		basicstyles : 'Osnovni stilovi',
+		paragraph : 'Paragraf',
+		links : 'Veze',
+		insert : 'Umetni',
+		styles : 'Stilovi',
+		colors : 'Boje',
+		tools : 'Alatke'
+	},
+
+	bidi :
+	{
+		ltr : 'Smjer teksta s lijeva na desno',
+		rtl : 'Smjer teksta s desna na lijevo'
+	},
+
+	docprops :
+	{
+		label : 'Svojstva dokumenta',
+		title : 'Svojstva dokumenta',
+		design : 'Dizajn',
+		meta : 'Meta Data',
+		chooseColor : 'Odaberi',
+		other : '<drugi>',
+		docTitle :	'Naslov stranice',
+		charset : 	'Enkodiranje znakova',
+		charsetOther : 'Ostalo enkodiranje znakova',
+		charsetASCII : 'ASCII',
+		charsetCE : 'Središnja Europa',
+		charsetCT : 'Tradicionalna kineska (Big5)',
+		charsetCR : 'Ćirilica',
+		charsetGR : 'Grčka',
+		charsetJP : 'Japanska',
+		charsetKR : 'Koreanska',
+		charsetTR : 'Turska',
+		charsetUN : 'Unicode (UTF-8)',
+		charsetWE : 'Zapadna Europa',
+		docType : 'Zaglavlje vrste dokumenta',
+		docTypeOther : 'Ostalo zaglavlje vrste dokumenta',
+		xhtmlDec : 'Ubaci XHTML deklaracije',
+		bgColor : 'Boja pozadine',
+		bgImage : 'URL slike pozadine',
+		bgFixed : 'Pozadine se ne pomiče',
+		txtColor : 'Boja teksta',
+		margin : 'Margine stranice',
+		marginTop : 'Vrh',
+		marginLeft : 'Lijevo',
+		marginRight : 'Desno',
+		marginBottom : 'Dolje',
+		metaKeywords : 'Ključne riječi dokumenta (odvojene zarezom)',
+		metaDescription : 'Opis dokumenta',
+		metaAuthor : 'Autor',
+		metaCopyright : 'Autorska prava',
+		previewHtml : '<p>Ovo je neki <strong>primjer teksta</strong>. Vi koristite <a href="javascript:void(0)">CKEditor</a>.</p>'
+	}
 };
