@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -80,7 +80,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 	function isListItem( node )
 	{
-		return node.type = CKEDITOR.NODE_ELEMENT && node.is( 'li' );
+		return node.type == CKEDITOR.NODE_ELEMENT && node.is( 'li' );
 	}
 
 	indentCommand.prototype = {
@@ -142,8 +142,11 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				{
 					listArray[ i ].indent += indentOffset;
 					// Make sure the newly created sublist get a brand-new element of the same type. (#5372)
-					var listRoot = listArray[ i ].parent;
-					listArray[ i ].parent = new CKEDITOR.dom.element( listRoot.getName(), listRoot.getDocument() );
+					if ( indentOffset > 0 )
+					{
+						var listRoot = listArray[ i ].parent;
+						listArray[ i ].parent = new CKEDITOR.dom.element( listRoot.getName(), listRoot.getDocument() );
+					}
 				}
 
 				for ( i = lastItem.getCustomData( 'listarray_index' ) + 1 ;
