@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -35,6 +35,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 		var createInstance = function()	// Create new instance every time Document is created.
 		{
+			if( plugin.instances[ editor.name ] )
+				plugin.instances[ editor.name ].destroy();
+
 			var config = editor.config;
 			// Initialise Scayt instance.
 			var oParams = {};
@@ -78,7 +81,6 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				oParams.id = plugin.getControlId( editor );
 
 			var scayt_control = new window.scayt( oParams );
-
 			scayt_control.afterMarkupRemove.push( function( node )
 			{
 				( new CKEDITOR.dom.element( node, scayt_control.document ) ).mergeSiblings();
@@ -102,13 +104,16 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			editor.fire( 'showScaytState' );
 		};
 
-		editor.on( 'contentDom', createInstance );
+		editor.on( 'contentDom', function(ev)
+			{
+				createInstance();
+			});
 		editor.on( 'contentDomUnload', function()
 			{
 				// Remove scripts.
 				var scripts = CKEDITOR.document.getElementsByTag( 'script' ),
 					scaytIdRegex =  /^dojoIoScript(\d+)$/i,
-					scaytSrcRegex =  /^https?:\/\/svc\.spellchecker\.net\/spellcheck\/script\/ssrv\.cgi/i;
+					scaytSrcRegex =  /^https?:\/\/svc\.webspellchecker\.net\/spellcheck\/script\/ssrv\.cgi/i;
 
 				for ( var i=0; i < scripts.count(); i++ )
 				{
@@ -123,20 +128,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 		editor.on( 'beforeCommandExec', function( ev )		// Disable SCAYT before Source command execution.
 			{
-				if ( ( ev.data.name == 'source' || ev.data.name == 'newpage' ) && editor.mode == 'wysiwyg' )
-				{
-					var scayt_instance = plugin.getScayt( editor );
-					if ( scayt_instance )
-					{
-						plugin.setPaused( editor, !scayt_instance.disabled );
-						// store a control id for restore a specific scayt control settings
-						plugin.setControlId( editor, scayt_instance.id );
-						scayt_instance.destroy( true );
-						delete plugin.instances[ editor.name ];
-					}
-				}
-				// Catch on source mode switch off (#5720)
-				else if ( ev.data.name == 'source'  && editor.mode == 'source' )
+				if ( ev.data.name == 'source'  && editor.mode == 'source' )
 					plugin.markControlRestore( editor );
 			});
 
@@ -148,7 +140,6 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				if ( editor.mode == 'wysiwyg' && ( ev.data.name == 'undo' || ev.data.name == 'redo' ) )
 					window.setTimeout( function() { plugin.getScayt( editor ).refresh(); }, 10 );
 			});
-
 		editor.on( 'destroy', function( ev )
 			{
 				var editor = ev.editor,
@@ -163,17 +154,19 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				plugin.setControlId( editor, scayt_instance.id );
 				scayt_instance.destroy( true );
 			});
-
-		// Listen to data manipulation to reflect scayt markup.
-		editor.on( 'afterSetData', function()
+		//#9439 after SetData method fires contentDom event and SCAYT create additional instanse
+		// This way we should destroy SCAYT on setData event when contenteditable Iframe was re-created
+		editor.on( 'setData', function( ev )
 			{
-				if ( plugin.isScaytEnabled( editor ) ) {
-					window.setTimeout( function()
-						{
-							var instance = plugin.getScayt( editor );
-							instance && instance.refresh();
-						}, 10 );
-				}
+				var scayt_instance = plugin.getScayt( editor );
+					if ( scayt_instance )
+					{
+						plugin.setPaused( editor, !scayt_instance.disabled );
+						// store a control id for restore a specific scayt control settings
+						plugin.setControlId( editor, scayt_instance.id );
+						scayt_instance.destroy( true );
+						delete plugin.instances[ editor.name ];
+					}
 			});
 
 		// Reload spell-checking for current word after insertion completed.
@@ -374,9 +367,14 @@ CKEDITOR.plugins.scayt =
 				return editor.fire( 'showScaytState' );
 
 			if ( this.engineLoaded === true )
-				return onEngineLoad.apply( editor );	// Add new instance.
-			else if ( this.engineLoaded == -1 )			// We are waiting.
+			{
+				return onEngineLoad.apply( editor );
+			}
+				// Add new instance.
+			else if ( this.engineLoaded == -1 )
+			{	// We are waiting.
 				return CKEDITOR.on( 'scaytReady', function(){ onEngineLoad.apply( editor ); } );	// Use function(){} to avoid rejection as duplicate.
+			}
 
 			CKEDITOR.on( 'scaytReady', onEngineLoad, editor );
 			CKEDITOR.on( 'scaytReady', function()
@@ -394,7 +392,7 @@ CKEDITOR.plugins.scayt =
 			var protocol = document.location.protocol;
 			// Default to 'http' for unknown.
 			protocol = protocol.search( /https?:/) != -1? protocol : 'http:';
-			var baseUrl  = 'svc.spellchecker.net/scayt26/loader__base.js';
+			var baseUrl  = 'svc.webspellchecker.net/scayt26/loader__base.js';
 
 			var scaytUrl  =  editor.config.scayt_srcUrl || ( protocol + '//' + baseUrl );
 			var scaytConfigBaseUrl =  plugin.parseUrl( scaytUrl ).path +  '/';
@@ -427,7 +425,9 @@ CKEDITOR.plugins.scayt =
 				);
 			}
 			else
+			{
 				CKEDITOR.fireOnce( 'scaytReady' );
+			}
 
 			return null;
 		},
@@ -658,10 +658,7 @@ CKEDITOR.plugins.scayt =
 							return null;
 
 						var sLang = scayt_control.getLang(),
-							_r = {},
 							items_suggestion = window.scayt.getSuggestion( word, sLang );
-						if ( !items_suggestion || !items_suggestion.length )
-							return null;
 						// Remove unused commands and menuitems
 						for ( var m in moreSuggestions )
 						{
@@ -686,49 +683,60 @@ CKEDITOR.plugins.scayt =
 						var contextCommands = editor.config.scayt_contextCommands || 'all';
 						contextCommands = contextCommands.split( '|' );
 
-						for ( var i = 0, l = items_suggestion.length; i < l; i += 1 )
-						{
-							var commandName = 'scayt_suggestion_' + items_suggestion[i].replace( ' ', '_' );
-							var exec = ( function( el, s )
-								{
-									return {
-										exec: function()
-										{
-											scayt_control.replace( el, s );
-										}
-									};
-								})( node, items_suggestion[i] );
+						if ( items_suggestion && items_suggestion.length ) {
+							for ( var i = 0, l = items_suggestion.length; i < l; i += 1 )
+							{
+								var commandName = 'scayt_suggestion_' + items_suggestion[i].replace( ' ', '_' );
+								var exec = ( function( el, s )
+									{
+										return {
+											exec: function()
+											{
+												scayt_control.replace(el, s);
+											}
+										};
+									})( node, items_suggestion[i] );
 
-							if ( i < maxSuggestions )
-							{
-								addButtonCommand( editor, 'button_' + commandName, items_suggestion[i],
-									commandName, exec, 'scayt_suggest', i + 1 );
-								_r[ commandName ] = CKEDITOR.TRISTATE_OFF;
-								mainSuggestions[ commandName ] = CKEDITOR.TRISTATE_OFF;
+								if ( i < maxSuggestions )
+								{
+									addButtonCommand( editor, 'button_' + commandName, items_suggestion[i],
+										commandName, exec, 'scayt_suggest', i + 1 );
+									mainSuggestions[ commandName ] = CKEDITOR.TRISTATE_OFF;
+								}
+								else if ( moreSuggestionsUnable == 'on' )
+								{
+									addButtonCommand( editor, 'button_' + commandName, items_suggestion[i],
+										commandName, exec, 'scayt_moresuggest', i + 1 );
+									moreSuggestions[ commandName ] = CKEDITOR.TRISTATE_OFF;
+									moreSuggestionsUnableAdded = true;
+								}
 							}
-							else if ( moreSuggestionsUnable == 'on' )
+
+							if ( moreSuggestionsUnableAdded )
 							{
-								addButtonCommand( editor, 'button_' + commandName, items_suggestion[i],
-									commandName, exec, 'scayt_moresuggest', i + 1 );
-								moreSuggestions[ commandName ] = CKEDITOR.TRISTATE_OFF;
-								moreSuggestionsUnableAdded = true;
+								// Register the More suggestions group;
+								editor.addMenuItem( 'scayt_moresuggest',
+								{
+									label : editor.lang.scayt.moreSuggestions,
+									group : 'scayt_moresuggest',
+									order : 10,
+									getItems : function()
+									{
+										return moreSuggestions;
+									}
+								});
+								mainSuggestions[ 'scayt_moresuggest' ] = CKEDITOR.TRISTATE_OFF;
 							}
 						}
-
-						if ( moreSuggestionsUnableAdded )
-						{
-							// Register the More suggestions group;
-							editor.addMenuItem( 'scayt_moresuggest',
+						else {
+							// "No suggestions" feature
+							editor.addMenuItem( 'scayt_nosuggest',
 							{
-								label : lang.moreSuggestions,
-								group : 'scayt_moresuggest',
-								order : 10,
-								getItems : function()
-								{
-									return moreSuggestions;
-								}
+								label : editor.lang.scayt.noSuggestions ? editor.lang.scayt.noSuggestions : (editor.lang.spellCheck.noSuggestions ? editor.lang.spellCheck.noSuggestions : 'No suggestions'),
+								group : 'scayt_suggest',
+								order : 1
 							});
-							mainSuggestions[ 'scayt_moresuggest' ] = CKEDITOR.TRISTATE_OFF;
+							mainSuggestions[ 'scayt_nosuggest' ] = CKEDITOR.TRISTATE_OFF;
 						}
 
 						if ( in_array( 'all', contextCommands )  || in_array( 'ignore', contextCommands)  )
@@ -821,27 +829,28 @@ CKEDITOR.plugins.scayt =
 })();
 
 /**
- * If enabled (true), turns on SCAYT automatically after loading the editor.
+ * If enabled (set to <code>true</code>), turns on SCAYT automatically
+ * after loading the editor.
  * @name CKEDITOR.config.scayt_autoStartup
  * @type Boolean
- * @default false
+ * @default <code>false</code>
  * @example
  * config.scayt_autoStartup = true;
  */
 
 /**
  * Defines the number of SCAYT suggestions to show in the main context menu.
- * The possible values are:
+ * Possible values are:
  * <ul>
- *	<li>0 (zero): All suggestions are displayed in the main context menu.</li>
- *	<li>Positive number: The maximum number of suggestions to shown in context
- *		menu. Other entries will be shown in "More Suggestions" sub-menu.</li>
- *	<li>Negative number: No suggestions are shown in the main context menu. All
- *		entries will be listed in the "Suggestions" sub-menu.</li>
+ *	<li><code>0</code> (zero) &ndash; All suggestions are displayed in the main context menu.</li>
+ *	<li>Positive number &ndash; The maximum number of suggestions to show in the context
+ *		menu. Other entries will be shown in the "More Suggestions" sub-menu.</li>
+ *	<li>Negative number &ndash; No suggestions are shown in the main context menu. All
+ *		entries will be listed in the the "Suggestions" sub-menu.</li>
  * </ul>
  * @name CKEDITOR.config.scayt_maxSuggestions
  * @type Number
- * @default 5
+ * @default <code>5</code>
  * @example
  * // Display only three suggestions in the main context menu.
  * config.scayt_maxSuggestions = 3;
@@ -851,11 +860,11 @@ CKEDITOR.plugins.scayt =
  */
 
 /**
- * Sets the customer ID for SCAYT. Required for migration from free version
- * with banner to paid version.
+ * Sets the customer ID for SCAYT. Required for migration from free,
+ * ad-supported version to paid, ad-free version.
  * @name CKEDITOR.config.scayt_customerid
  * @type String
- * @default ''
+ * @default <code>''</code>
  * @example
  * // Load SCAYT using my customer ID.
  * config.scayt_customerid  = 'your-encrypted-customer-id';
@@ -863,10 +872,10 @@ CKEDITOR.plugins.scayt =
 
 /**
  * Enables/disables the "More Suggestions" sub-menu in the context menu.
- * The possible values are "on" or "off".
+ * Possible values are <code>on</code> and <code>off</code>.
  * @name CKEDITOR.config.scayt_moreSuggestions
  * @type String
- * @default 'on'
+ * @default <code>'on'</code>
  * @example
  * // Disables the "More Suggestions" sub-menu.
  * config.scayt_moreSuggestions = 'off';
@@ -874,91 +883,99 @@ CKEDITOR.plugins.scayt =
 
 /**
  * Customizes the display of SCAYT context menu commands ("Add Word", "Ignore"
- * and "Ignore All"). It must be a string with one or more of the following
- * words separated by a pipe ("|"):
+ * and "Ignore All"). This must be a string with one or more of the following
+ * words separated by a pipe character ("|"):
  * <ul>
- *	<li>"off": disables all options.</li>
- *	<li>"all": enables all options.</li>
- *	<li>"ignore": enables the "Ignore" option.</li>
- *	<li>"ignoreall": enables the "Ignore All" option.</li>
- *	<li>"add": enables the "Add Word" option.</li>
+ *	<li><code>off</code> &ndash; disables all options.</li>
+ *	<li><code>all</code> &ndash; enables all options.</li>
+ *	<li><code>ignore</code> &ndash; enables the "Ignore" option.</li>
+ *	<li><code>ignoreall</code> &ndash; enables the "Ignore All" option.</li>
+ *	<li><code>add</code> &ndash; enables the "Add Word" option.</li>
  * </ul>
  * @name CKEDITOR.config.scayt_contextCommands
  * @type String
- * @default 'all'
+ * @default <code>'all'</code>
  * @example
  * // Show only "Add Word" and "Ignore All" in the context menu.
  * config.scayt_contextCommands = 'add|ignoreall';
  */
 
 /**
- * Sets the default spellchecking language for SCAYT.
+ * Sets the default spell checking language for SCAYT. Possible values are:
+ * <code>en_US</code>, <code>en_GB</code>, <code>pt_BR</code>, <code>da_DK</code>,
+ * <code>nl_NL</code>, <code>en_CA</code>, <code>fi_FI</code>, <code>fr_FR</code>,
+ * <code>fr_CA</code>, <code>de_DE</code>, <code>el_GR</code>, <code>it_IT</code>,
+ * <code>nb_NO</code>, <code>pt_PT</code>, <code>es_ES</code>, <code>sv_SE</code>.
  * @name CKEDITOR.config.scayt_sLang
  * @type String
- * @default 'en_US'
+ * @default <code>'en_US'</code>
  * @example
  * // Sets SCAYT to German.
  * config.scayt_sLang = 'de_DE';
  */
 
 /**
- * Sets the visibility of the SCAYT tabs in the settings dialog and toolbar
- * button. The value must contain a "1" (enabled) or "0" (disabled) number for
- * each of the following entries, in this precise order, separated by a
- * comma (","): "Options", "Languages" and "Dictionary".
+ * Sets the visibility of particular tabs in the SCAYT dialog window and toolbar
+ * button. This setting must contain a <code>1</code> (enabled) or <code>0</code>
+ * (disabled) value for each of the following entries, in this precise order,
+ * separated by a comma (","): "Options", "Languages", and "Dictionary".
  * @name CKEDITOR.config.scayt_uiTabs
  * @type String
- * @default '1,1,1'
+ * @default <code>'1,1,1'</code>
  * @example
- * // Hide the "Languages" tab.
+ * // Hides the "Languages" tab.
  * config.scayt_uiTabs = '1,0,1';
  */
 
 
 /**
- * Set the URL to SCAYT core. Required to switch to licensed version of SCAYT application.
- * Further details at http://wiki.spellchecker.net/doku.php?id=3rd:wysiwyg:fckeditor:wscckf3l .
+ * Sets the URL to SCAYT core. Required to switch to the licensed version of SCAYT application.
+ * Further details available at
+ * <a href="http://wiki.webspellchecker.net/doku.php?id=migration:hosredfreetolicensedck">
+ * http://wiki.webspellchecker.net/doku.php?id=migration:hosredfreetolicensedck</a>.
  * @name CKEDITOR.config.scayt_srcUrl
  * @type String
- * @default ''
+ * @default <code>''</code>
  * @example
  * config.scayt_srcUrl = "http://my-host/spellcheck/lf/scayt/scayt.js";
  */
 
 /**
- * Links SCAYT to custom dictionaries. It's a string containing dictionary ids
- * separared by commas (","). Available only for licensed version.
- * Further details at http://wiki.spellchecker.net/doku.php?id=custom_dictionary_support .
+ * Links SCAYT to custom dictionaries. This is a string containing dictionary IDs
+ * separared by commas (","). Available only for the licensed version.
+ * Further details at
+ * <a href="http://wiki.webspellchecker.net/doku.php?id=installationandconfiguration:customdictionaries:licensed">
+ * http://wiki.webspellchecker.net/doku.php?id=installationandconfiguration:customdictionaries:licensed</a>.
  * @name CKEDITOR.config.scayt_customDictionaryIds
  * @type String
- * @default ''
+ * @default <code>''</code>
  * @example
  * config.scayt_customDictionaryIds = '3021,3456,3478"';
  */
 
 /**
- * Makes it possible to activate a custom dictionary on SCAYT. The user
- * dictionary name must be used. Available only for licensed version.
+ * Makes it possible to activate a custom dictionary in SCAYT. The user
+ * dictionary name must be used. Available only for the licensed version.
  * @name CKEDITOR.config.scayt_userDictionaryName
  * @type String
- * @default ''
+ * @default <code>''</code>
  * @example
  * config.scayt_userDictionaryName = 'MyDictionary';
  */
 
 /**
- * Define order of placing of SCAYT context menu items by groups.
- * It must be a string with one or more of the following
- * words separated by a pipe ("|"):
+ * Defines the order SCAYT context menu items by groups.
+ * This must be a string with one or more of the following
+ * words separated by a pipe character ("|"):
  * <ul>
- *     <li>'suggest'     - main suggestion word list,</li>
- *     <li>'moresuggest' - more suggestions word list,</li>
- *     <li>'control'     - SCAYT commands, such as 'Ignore' and 'Add Word'</li>
+ *     <li><code>suggest</code> &ndash; main suggestion word list,</li>
+ *     <li><code>moresuggest</code> &ndash; more suggestions word list,</li>
+ *     <li><code>control</code> &ndash; SCAYT commands, such as "Ignore" and "Add Word".</li>
  * </ul>
  *
  * @name CKEDITOR.config.scayt_contextMenuItemsOrder
  * @type String
- * @default 'suggest|moresuggest|control'
+ * @default <code>'suggest|moresuggest|control'</code>
  * @example
  * config.scayt_contextMenuItemsOrder = 'moresuggest|control|suggest';
  */
