@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -72,21 +72,32 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 	function rangeRequiresFix( range )
 	{
-		function isInlineCt( node )
+		function isTextCt( node, isAtEnd )
 		{
-			return node && node.type == CKEDITOR.NODE_ELEMENT
-					&& node.getName() in CKEDITOR.dtd.$removeEmpty;
+			if ( !node || node.type == CKEDITOR.NODE_TEXT )
+				return false;
+
+			var testRng = range.clone();
+			return testRng[ 'moveToElementEdit' + ( isAtEnd ? 'End' : 'Start' ) ]( node );
 		}
 
-		var start = range.startContainer,
-			offset = range.startOffset;
+		var ct = range.startContainer;
 
-		if ( start.type == CKEDITOR.NODE_TEXT )
-			return false;
+		var previous = range.getPreviousNode( isVisible, null, ct ),
+			next = range.getNextNode( isVisible, null, ct );
 
-		// 1. Empty inline element. <span>^</span>
-		// 2. Adjoin to inline element. <p><strong>text</strong>^</p>
-		return !CKEDITOR.tools.trim( start.getHtml() ) ? isInlineCt( start ) : isInlineCt( start.getChild( offset - 1 ) ) || isInlineCt( start.getChild( offset ) );
+		// Any adjacent text container may absorb the cursor, e.g.
+		// <p><strong>text</strong>^foo</p>
+		// <p>foo^<strong>text</strong></p>
+		// <div>^<p>foo</p></div>
+		if ( isTextCt( previous ) || isTextCt( next, 1 ) )
+			return true;
+
+		// Empty block/inline element is also affected. <span>^</span>, <p>^</p> (#7222)
+		if ( !( previous || next ) && !( ct.type == CKEDITOR.NODE_ELEMENT && ct.isBlockBoundary() && ct.getBogus() ) )
+			return true;
+
+		return false;
 	}
 
 	var selectAllCmd =
@@ -154,11 +165,54 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		var fillingChar = doc && doc.removeCustomData( 'cke-fillingChar' );
 		if ( fillingChar )
 		{
+			var bm,
+			sel = doc.getSelection().getNative(),
+			// Be error proof.
+			range = sel && sel.type != 'None' && sel.getRangeAt( 0 );
+
+			// Text selection position might get mangled by
+			// subsequent dom modification, save it now for restoring. (#8617)
+			if ( fillingChar.getLength() > 1
+				 && range && range.intersectsNode( fillingChar.$ ) )
+			{
+				bm = [ sel.anchorOffset, sel.focusOffset ];
+
+				// Anticipate the offset change brought by the removed char.
+				var startAffected = sel.anchorNode == fillingChar.$ && sel.anchorOffset > 0,
+					endAffected = sel.focusNode == fillingChar.$ && sel.focusOffset > 0;
+				startAffected && bm[ 0 ]--;
+				endAffected && bm[ 1 ]--;
+
+				// Revert the bookmark order on reverse selection.
+				isReversedSelection( sel ) && bm.unshift( bm.pop() );
+			}
+
 			// We can't simply remove the filling node because the user
 			// will actually enlarge it when typing, so we just remove the
 			// invisible char from it.
 			fillingChar.setText( fillingChar.getText().replace( /\u200B/g, '' ) );
-			fillingChar = 0;
+
+			// Restore the bookmark.
+			if ( bm )
+			{
+				var rng = sel.getRangeAt( 0 );
+				rng.setStart( rng.startContainer, bm[ 0 ] );
+				rng.setEnd( rng.startContainer, bm[ 1 ] );
+				sel.removeAllRanges();
+				sel.addRange( rng );
+			}
+		}
+	}
+
+	function isReversedSelection( sel )
+	{
+		if ( !sel.isCollapsed )
+		{
+			var range = sel.getRangeAt( 0 );
+			// Potentially alter an reversed selection range.
+			range.setStart( sel.anchorNode, sel.anchorOffset );
+			range.setEnd( sel.focusNode, sel.focusOffset );
+			return range.collapsed;
 		}
 	}
 
@@ -172,20 +226,6 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			{
 				editor.on( 'selectionChange', function() { checkFillingChar( editor.document ); } );
 				editor.on( 'beforeSetMode', function() { removeFillingChar( editor.document ); } );
-				editor.on( 'key', function( e )
-					{
-						// Remove the filling char before some keys get
-						// executed, so they'll not get blocked by it.
-						switch ( e.data.keyCode )
-						{
-							case 13 :	// ENTER
-							case CKEDITOR.SHIFT + 13 :	// SHIFT-ENTER
-							case 37 :	// LEFT-ARROW
-							case 39 :	// RIGHT-ARROW
-							case 8 :	// BACKSPACE
-								removeFillingChar( editor.document );
-						}
-					}, null, null, 10 );
 
 				var fillingCharBefore,
 					resetSelection;
@@ -232,6 +272,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			editor.on( 'contentDom', function()
 				{
 					var doc = editor.document,
+						outerDoc = CKEDITOR.document,
 						body = doc.getBody(),
 						html = doc.getDocumentElement();
 
@@ -256,29 +297,22 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								if ( evt.data.$.srcElement.nodeName != 'BODY' )
 									return;
 
-								// If we have saved a range, restore it at this
-								// point.
-								if ( savedRange )
+								// Give the priority to locked selection since it probably
+								// reflects the actual situation, besides locked selection
+								// could be interfered because of text nodes normalizing.
+								// (#6083, #6987)
+								var lockedSelection = doc.getCustomData( 'cke_locked_selection' );
+								if ( lockedSelection )
 								{
-									if ( restoreEnabled )
-									{
-										// Well not break because of this.
-										try
-										{
-											savedRange.select();
-										}
-										catch (e)
-										{}
-
-										// Update locked selection because of the normalized text nodes. (#6083, #6987)
-										var lockedSelection = doc.getCustomData( 'cke_locked_selection' );
-										if ( lockedSelection )
-										{
-											lockedSelection.unlock();
-											lockedSelection.lock();
-										}
-									}
-
+									lockedSelection.unlock( 1 );
+									lockedSelection.lock();
+								}
+								// Then check ff we have saved a range, restore it at this
+								// point.
+								else if ( savedRange && restoreEnabled )
+								{
+									// Well not break because of this.
+									try { savedRange.select(); } catch (e) {}
 									savedRange = null;
 								}
 							});
@@ -303,20 +337,21 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								restoreEnabled = 1;
 							});
 
-						// IE before version 8 will leave cursor blinking inside the document after
-						// editor blurred unless we clean up the selection. (#4716)
-						if ( CKEDITOR.env.ie && CKEDITOR.env.version < 8 )
+						// [IE] Iframe will still keep the selection when blurred, if
+						// focus is moved onto a non-editing host, e.g. link or button, but
+						// it becomes a problem for the object type selection, since the resizer
+						// handler attached on it will mark other part of the UI, especially
+						// for the dialog. (#8157)
+						// [IE<8] Even worse For old IEs, the cursor will not vanish even if
+						// the selection has been moved to another text input in some cases. (#4716)
+						//
+						// Now the range restore is disabled, so we simply force IE to clean
+						// up the selection before blur.
+						CKEDITOR.env.ie && editor.on( 'blur', function()
 						{
-							editor.on( 'blur', function( evt )
-							{
-								// Try/Catch to avoid errors if the editor is hidden. (#6375)
-								try
-								{
-									editor.document && editor.document.$.selection.empty();
-								}
-								catch (e) {}
-							});
-						}
+							// Error proof when the editor is not visible. (#6375)
+							try{ doc.$.selection.empty(); } catch ( er){}
+						});
 
 						// Listening on document element ensures that
 						// scrollbar is included. (#5280)
@@ -333,20 +368,6 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 							restoreEnabled = 1;
 						});
 
-						// In IE6/7 the blinking cursor appears, but contents are
-						// not editable. (#5634)
-						if ( CKEDITOR.env.ie && ( CKEDITOR.env.ie7Compat || CKEDITOR.env.version < 8 || CKEDITOR.env.quirks ) )
-						{
-							// The 'click' event is not fired when clicking the
-							// scrollbars, so we can use it to check whether
-							// the empty space following <body> has been clicked.
-							html.on( 'click', function( evt )
-							{
-								if ( evt.data.getTarget().getName() == 'html' )
-									editor.getSelection().getRanges()[ 0 ].select();
-							});
-						}
-
 						var scroll;
 						// IE fires the "selectionchange" event when clicking
 						// inside a selection. We don't want to capture that.
@@ -391,7 +412,117 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								saveSelection();
 							});
 
+						// When content doc is in standards mode, IE doesn't produce text selection
+						// when click on the region outside of body, we emulate
+						// the correct behavior here. (#1659, #7932, # 9097)
+						if ( doc.$.compatMode != 'BackCompat' )
+						{
+							if ( CKEDITOR.env.ie7Compat || CKEDITOR.env.ie6Compat )
+							{
+								function moveRangeToPoint( range, x, y )
+								{
+									// Error prune in IE7. (#9034, #9110)
+									try { range.moveToPoint( x, y ); } catch ( e ) {}
+								}
 
+								html.on( 'mousedown', function( evt )
+								{
+									// Expand the text range along with mouse move.
+									function onHover( evt )
+									{
+										evt = evt.data.$;
+										if ( textRng )
+										{
+											// Read the current cursor.
+											var rngEnd = body.$.createTextRange();
+
+											moveRangeToPoint( rngEnd, evt.x, evt.y );
+
+											// Handle drag directions.
+											textRng.setEndPoint(
+												startRng.compareEndPoints( 'StartToStart', rngEnd ) < 0 ?
+												'EndToEnd' :
+												'StartToStart',
+												rngEnd );
+
+											// Update selection with new range.
+											textRng.select();
+										}
+									}
+
+									function removeListeners()
+									{
+										outerDoc.removeListener( 'mouseup', onSelectEnd );
+										html.removeListener( 'mouseup', onSelectEnd );
+									}
+
+									function onSelectEnd()
+									{
+
+										html.removeListener( 'mousemove', onHover );
+										removeListeners();
+
+										// Make it in effect on mouse up. (#9022)
+										textRng.select();
+									}
+
+									evt = evt.data;
+
+									// We're sure that the click happens at the region
+									// outside body, but not on scrollbar.
+									if ( evt.getTarget().is( 'html' ) &&
+											 evt.$.x < html.$.clientWidth &&
+											 evt.$.y < html.$.clientHeight )
+									{
+										// Start to build the text range.
+										var textRng = body.$.createTextRange();
+										moveRangeToPoint( textRng, evt.$.x, evt.$.y );
+										// Records the dragging start of the above text range.
+										var startRng = textRng.duplicate();
+
+										html.on( 'mousemove', onHover );
+										outerDoc.on( 'mouseup', onSelectEnd );
+										html.on( 'mouseup', onSelectEnd );
+									}
+								});
+							}
+
+							// It's much simpler for IE > 8, we just need to reselect the reported range.
+							if ( CKEDITOR.env.ie8 )
+							{
+								html.on( 'mousedown', function( evt )
+								{
+									if ( evt.data.getTarget().is( 'html' ) )
+									{
+										// Limit the text selection mouse move inside of editable. (#9715)
+										outerDoc.on( 'mouseup', onSelectEnd );
+										html.on( 'mouseup', onSelectEnd );
+									}
+
+								});
+
+								function removeListeners()
+								{
+									outerDoc.removeListener( 'mouseup', onSelectEnd );
+									html.removeListener( 'mouseup', onSelectEnd );
+								}
+
+								function onSelectEnd()
+								{
+									removeListeners();
+
+									// The event is not fired when clicking on the scrollbars,
+									// so we can safely check the following to understand
+									// whether the empty space following <body> has been clicked.
+										var sel = CKEDITOR.document.$.selection,
+											range = sel.createRange();
+										// The selection range is reported on host, but actually it should applies to the content doc.
+										if ( sel.type != 'None' && range.parentElement().ownerDocument == doc.$ )
+											range.select();
+								}
+							}
+
+						}
 						// IE is the only to provide the "selectionchange"
 						// event.
 						doc.on( 'selectionchange', saveSelection );
@@ -441,7 +572,8 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 									return;
 								}
 
-								savedRange = nativeSel && sel.getRanges()[ 0 ];
+								// Not break because of this. (#9132)
+								try{ savedRange = nativeSel && sel.getRanges()[ 0 ]; } catch( er ) {}
 
 								checkSelectionChangeTimeout.call( editor );
 							}
@@ -455,6 +587,33 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 						doc.on( 'mouseup', checkSelectionChangeTimeout, editor );
 						doc.on( 'keyup', checkSelectionChangeTimeout, editor );
+						doc.on( 'selectionchange', checkSelectionChangeTimeout, editor );
+					}
+
+					if ( CKEDITOR.env.webkit )
+					{
+						// Before keystroke is handled by editor, check to remove the filling char.
+						doc.on( 'keydown', function( evt )
+						{
+							var key = evt.data.getKey();
+							// Remove the filling char before some keys get
+							// executed, so they'll not get blocked by it.
+							switch ( key )
+							{
+								case 13 :	// ENTER
+								case 33 :	// PAGEUP
+								case 34 :	// PAGEDOWN
+								case 35 :	// HOME
+								case 36 :	// END
+								case 37 :	// LEFT-ARROW
+								case 39 :	// RIGHT-ARROW
+								case 8 :	// BACKSPACE
+								case 45 :	// INS
+								case 46 :	// DEl
+									removeFillingChar( editor.document );
+							}
+
+						}, null, null, -1 );
 					}
 				});
 
@@ -468,16 +627,32 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 					command : 'selectAll'
 				});
 
-			editor.selectionChange = checkSelectionChangeTimeout;
+			/**
+			 * Check if to fire the {@link CKEDITOR.editor#selectionChange} event
+			 * for the current editor instance.
+			 *
+			 * @param {Boolean} checkNow Check immediately without any delay.
+			 */
+			editor.selectionChange = function( checkNow )
+			{
+				( checkNow ? checkSelectionChange : checkSelectionChangeTimeout ).call( this );
+			};
+
+			// IE9 might cease to work if there's an object selection inside the iframe (#7639).
+			CKEDITOR.env.ie9Compat && editor.on( 'destroy', function()
+			{
+				var sel = editor.getSelection();
+				sel && sel.getNative().clear();
+			}, null, null, 9 );
 		}
 	});
 
 	/**
 	 * Gets the current selection from the editing area when in WYSIWYG mode.
-	 * @returns {CKEDITOR.dom.selection} A selection object or null if not on
+	 * @returns {CKEDITOR.dom.selection} A selection object or null if not in
 	 *		WYSIWYG mode or no selection is available.
 	 * @example
-	 * var selection = CKEDITOR.instances.editor1.<b>getSelection()</b>;
+	 * var selection = CKEDITOR.instances.editor1.<strong>getSelection()</strong>;
 	 * alert( selection.getType() );
 	 */
 	CKEDITOR.editor.prototype.getSelection = function()
@@ -494,7 +669,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 	 * Gets the current selection from the document.
 	 * @returns {CKEDITOR.dom.selection} A selection object.
 	 * @example
-	 * var selection = CKEDITOR.instances.editor1.document.<b>getSelection()</b>;
+	 * var selection = CKEDITOR.instances.editor1.document.<strong>getSelection()</strong>;
 	 * alert( selection.getType() );
 	 */
 	CKEDITOR.dom.document.prototype.getSelection = function()
@@ -513,11 +688,11 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 	CKEDITOR.SELECTION_NONE		= 1;
 
 	/**
-	 * Text or collapsed selection.
+	 * A text or a collapsed selection.
 	 * @constant
 	 * @example
 	 * if ( editor.getSelection().getType() == CKEDITOR.SELECTION_TEXT )
-	 *     alert( 'Text is selected' );
+	 *     alert( 'A text is selected' );
 	 */
 	CKEDITOR.SELECTION_TEXT		= 2;
 
@@ -533,7 +708,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 	/**
 	 * Manipulates the selection in a DOM document.
 	 * @constructor
+	 * @param {CKEDITOR.dom.document} document The DOM document that contains the selection.
 	 * @example
+	 * var sel = new <strong>CKEDITOR.dom.selection( CKEDITOR.document )</strong>;
 	 */
 	CKEDITOR.dom.selection = function( document )
 	{
@@ -551,14 +728,22 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 		/**
 		 * IE BUG: The selection's document may be a different document than the
-		 * editor document. Return null if that's the case.
+		 * editor document. Return null if that is the case.
 		 */
 		if ( CKEDITOR.env.ie )
 		{
-			var range = this.getNative().createRange();
-			if ( !range
-				|| ( range.item && range.item(0).ownerDocument != this.document.$ )
-				|| ( range.parentElement && range.parentElement().ownerDocument != this.document.$ ) )
+			// Avoid breaking because of it. (#8836)
+			try
+			{
+				var range = this.getNative().createRange();
+				if ( !range ||
+					 ( range.item && range.item( 0 ).ownerDocument != this.document.$ ) ||
+					 ( range.parentElement && range.parentElement().ownerDocument != this.document.$ ) )
+				{
+					throw 0;
+				}
+			}
+			catch ( e )
 			{
 				this.isInvalid = true;
 			}
@@ -578,9 +763,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		/**
 		 * Gets the native selection object from the browser.
 		 * @function
-		 * @returns {Object} The native selection object.
+		 * @returns {Object} The native browser selection object.
 		 * @example
-		 * var selection = editor.getSelection().<b>getNative()</b>;
+		 * var selection = editor.getSelection().<strong>getNative()</strong>;
 		 */
 		getNative :
 			CKEDITOR.env.ie ?
@@ -598,19 +783,19 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		 * Gets the type of the current selection. The following values are
 		 * available:
 		 * <ul>
-		 *		<li>{@link CKEDITOR.SELECTION_NONE} (1): No selection.</li>
-		 *		<li>{@link CKEDITOR.SELECTION_TEXT} (2): Text is selected or
-		 *			collapsed selection.</li>
-		 *		<li>{@link CKEDITOR.SELECTION_ELEMENT} (3): A element
-		 *			selection.</li>
+		 *		<li><code>{@link CKEDITOR.SELECTION_NONE}</code> (1): No selection.</li>
+		 *		<li><code>{@link CKEDITOR.SELECTION_TEXT}</code> (2): A text or a collapsed
+		 *			selection is selected.</li>
+		 *		<li><code>{@link CKEDITOR.SELECTION_ELEMENT}</code> (3): An element is
+		 *			selected.</li>
 		 * </ul>
 		 * @function
 		 * @returns {Number} One of the following constant values:
-		 *		{@link CKEDITOR.SELECTION_NONE}, {@link CKEDITOR.SELECTION_TEXT} or
-		 *		{@link CKEDITOR.SELECTION_ELEMENT}.
+		 *		<code>{@link CKEDITOR.SELECTION_NONE}</code>, <code>{@link CKEDITOR.SELECTION_TEXT}</code>, or
+		 *		<code>{@link CKEDITOR.SELECTION_ELEMENT}</code>.
 		 * @example
-		 * if ( editor.getSelection().<b>getType()</b> == CKEDITOR.SELECTION_TEXT )
-		 *     alert( 'Text is selected' );
+		 * if ( editor.getSelection().<strong>getType()</strong> == CKEDITOR.SELECTION_TEXT )
+		 *     alert( 'A text is selected' );
 		 */
 		getType :
 			CKEDITOR.env.ie ?
@@ -678,13 +863,15 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				},
 
 		/**
-		 * Retrieve the {@link CKEDITOR.dom.range} instances that represent the current selection.
-		 * Note: Some browsers returns multiple ranges even on a sequent selection, e.g. Firefox returns
-		 * one range for each table cell when one or more table row is selected.
-		 * @return {Array}
+		 * Retrieves the <code>{@link CKEDITOR.dom.range}</code> instances that represent the current selection.
+		 * Note: Some browsers return multiple ranges even for a continuous selection. Firefox, for example, returns
+		 * one range for each table cell when one or more table rows are selected.
+		 * @function
+		 * @param {Boolean} [onlyEditables] If set to <code>true</code>, this function retrives editable ranges only.
+		 * @return {Array} Range instances that represent the current selection.
 		 * @example
-		 * var ranges = selection.getRanges();
-		 * alert(ranges.length);
+		 * var ranges = selection.<strong>getRanges()</strong>;
+		 * alert( ranges.length );
 		 */
 		getRanges : (function()
 		{
@@ -717,7 +904,8 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 							endIndex = siblings.length - 1,
 							index = -1,
 							position,
-							distance;
+							distance,
+							container;
 
 						// Binary search over all element childs to test the range to see whether
 						// range is right on the boundary of one element.
@@ -738,12 +926,10 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								// e.g. <p>text<br />^<br /></p> (#7433)
 								if ( CKEDITOR.env.ie9Compat && child.tagName == 'BR' )
 								{
-									var bmId = 'cke_range_marker';
-									range.execCommand( 'CreateBookmark', false, bmId );
-									child = doc.getElementsByName( bmId )[ 0 ];
-									var offset = getNodeIndex( child );
-									parent.removeChild( child );
-									return { container : parent, offset : offset };
+									// "Fall back" to w3c selection.
+									var sel = doc.defaultView.getSelection();
+									return { container : sel[ start ? 'anchorNode' : 'focusNode' ],
+										offset : sel[ start ? 'anchorOffset' : 'focusOffset' ] };
 								}
 								else
 									return { container : parent, offset : getNodeIndex( child ) };
@@ -770,7 +956,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 							{
 								child = siblings[ siblings.length - 1 ];
 
-								if ( child.nodeType == CKEDITOR.NODE_ELEMENT )
+								if ( child.nodeType != CKEDITOR.NODE_TEXT )
 									return { container : parent, offset : siblings.length };
 								else
 									return { container : child, offset : child.nodeValue.length };
@@ -778,10 +964,17 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 
 							// Start the measuring until distance overflows, meanwhile count the text nodes.
 							var i = siblings.length;
-							while ( distance > 0 )
-								distance -= siblings[ --i ].nodeValue.length;
+							while ( distance > 0 && i > 0 )
+							{
+								sibling = siblings[ --i ];
+								if ( sibling.nodeType == CKEDITOR.NODE_TEXT )
+								{
+									container = sibling;
+									distance -= sibling.nodeValue.length;
+								}
+							}
 
-							return  { container : siblings[ i ], offset : -distance };
+							return  { container : container, offset : -distance };
 						}
 						// Test range was one offset beyond OR behind the anchored text node.
 						else
@@ -806,7 +999,11 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								try
 								{
 									sibling = child[ position > 0 ? 'previousSibling' : 'nextSibling' ];
-									distance -= sibling.nodeValue.length;
+									if ( sibling.nodeType == CKEDITOR.NODE_TEXT )
+									{
+										distance -= sibling.nodeValue.length;
+										container = sibling;
+									}
 									child = sibling;
 								}
 								// Measurement in IE could be somtimes wrong because of <select> element. (#4611)
@@ -816,7 +1013,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 								}
 							}
 
-							return { container : child, offset : position > 0 ? -distance : child.nodeValue.length + distance };
+							return { container : container, offset : position > 0 ? -distance : container.nodeValue.length + distance };
 						}
 					};
 
@@ -942,18 +1139,30 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 						if ( range.collapsed )
 							continue;
 
+						// Range may start inside a non-editable element,
+						// replace the range start after it.
+						if ( range.startContainer.isReadOnly() )
+						{
+							var current = range.startContainer;
+							while( current )
+							{
+								if ( current.is( 'body' ) || !current.isReadOnly() )
+									break;
+
+								if ( current.type == CKEDITOR.NODE_ELEMENT
+										&& current.getAttribute( 'contentEditable' ) == 'false' )
+									range.setStartAfter( current );
+
+								current = current.getParent();
+							}
+						}
+
 						var startContainer = range.startContainer,
 							endContainer = range.endContainer,
 							startOffset = range.startOffset,
 							endOffset = range.endOffset,
 							walkerRange = range.clone();
 
-						// Range may start inside a non-editable element, restart range
-						// by the end of it.
-						var readOnly;
-						if ( ( readOnly = startContainer.isReadOnly() ) )
-							range.setStartAfter( readOnly );
-
 						// Enlarge range start/end with text node to avoid walker
 						// being DOM destructive, it doesn't interfere our checking
 						// of elements below as well.
@@ -1016,7 +1225,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		 * @returns {CKEDITOR.dom.element} The element at the beginning of the
 		 *		selection.
 		 * @example
-		 * var element = editor.getSelection().<b>getStartElement()</b>;
+		 * var element = editor.getSelection().<strong>getStartElement()</strong>;
 		 * alert( element.getName() );
 		 */
 		getStartElement : function()
@@ -1092,12 +1301,12 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 * Gets the current selected element.
+		 * Gets the currently selected element.
 		 * @returns {CKEDITOR.dom.element} The selected element. Null if no
 		 *		selection is available or the selection type is not
-		 *		{@link CKEDITOR.SELECTION_ELEMENT}.
+		 *		<code>{@link CKEDITOR.SELECTION_ELEMENT}</code>.
 		 * @example
-		 * var element = editor.getSelection().<b>getSelectedElement()</b>;
+		 * var element = editor.getSelection().<strong>getSelectedElement()</strong>;
 		 * alert( element.getName() );
 		 */
 		getSelectedElement : function()
@@ -1114,6 +1323,74 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 				{
 					return self.getNative().createRange().item( 0 );
 				},
+				// If a table or list is fully selected.
+				function()
+				{
+					var root,
+						retval,
+						range  = self.getRanges()[ 0 ],
+						ancestor = range.getCommonAncestor( 1, 1 ),
+						tags = { table:1,ul:1,ol:1,dl:1 };
+
+					for ( var t in tags )
+					{
+						if ( ( root = ancestor.getAscendant( t, 1 ) ) )
+							break;
+					}
+
+					if ( root )
+					{
+						// Enlarging the start boundary.
+						var testRange = new CKEDITOR.dom.range( this.document );
+						testRange.setStartAt( root, CKEDITOR.POSITION_AFTER_START );
+						testRange.setEnd( range.startContainer, range.startOffset );
+
+						var enlargeables = CKEDITOR.tools.extend( tags, CKEDITOR.dtd.$listItem, CKEDITOR.dtd.$tableContent ),
+							walker = new CKEDITOR.dom.walker( testRange ),
+							// Check the range is at the inner boundary of the structural element.
+							guard = function( walker, isEnd )
+							{
+								return function( node, isWalkOut )
+								{
+									if ( node.type == CKEDITOR.NODE_TEXT && ( !CKEDITOR.tools.trim( node.getText() ) || node.getParent().data( 'cke-bookmark' ) ) )
+										return true;
+
+									var tag;
+									if ( node.type == CKEDITOR.NODE_ELEMENT )
+									{
+										tag = node.getName();
+
+										// Bypass bogus br at the end of block.
+										if ( tag == 'br' && isEnd && node.equals( node.getParent().getBogus() ) )
+											return true;
+
+										if ( isWalkOut && tag in enlargeables || tag in CKEDITOR.dtd.$removeEmpty )
+											return true;
+									}
+
+									walker.halted = 1;
+									return false;
+								};
+							};
+
+						walker.guard = guard( walker );
+
+						if ( walker.checkBackward() && !walker.halted )
+						{
+							walker = new CKEDITOR.dom.walker( testRange );
+							testRange.setStart( range.endContainer, range.endOffset );
+							testRange.setEndAt( root, CKEDITOR.POSITION_BEFORE_END );
+							walker.guard = guard( walker, 1 );
+							if ( walker.checkForward() && !walker.halted )
+								retval = root.$;
+						}
+					}
+
+					if ( !retval )
+						throw 0;
+
+					return retval;
+				},
 				// Figure it out by checking if there's a single enclosed
 				// node of the range.
 				function()
@@ -1138,12 +1415,43 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			return cache.selectedElement = ( node ? new CKEDITOR.dom.element( node ) : null );
 		},
 
+		/**
+		 * Retrieves the text contained within the range. An empty string is returned for non-text selection.
+		 * @returns {String} A string of text within the current selection.
+		 * @since 3.6.1
+		 * @example
+		 * var text = editor.getSelection().<strong>getSelectedText()</strong>;
+		 * alert( text );
+		 */
+		getSelectedText : function()
+		{
+			var cache = this._.cache;
+			if ( cache.selectedText !== undefined )
+				return cache.selectedText;
+
+			var text = '',
+				nativeSel = this.getNative();
+			if ( this.getType() == CKEDITOR.SELECTION_TEXT )
+				text = CKEDITOR.env.ie ? nativeSel.createRange().text : nativeSel.toString();
+
+			return ( cache.selectedText = text );
+		},
+
+		/**
+		 * Locks the selection made in the editor in order to make it possible to
+		 * manipulate it without browser interference. A locked selection is
+		 * cached and remains unchanged until it is released with the <code>#unlock</code>
+		 * method.
+		 * @example
+		 * editor.getSelection().<strong>lock()</strong>;
+		 */
 		lock : function()
 		{
 			// Call all cacheable function.
 			this.getRanges();
 			this.getStartElement();
 			this.getSelectedElement();
+			this.getSelectedText();
 
 			// The native selection is not available when locked.
 			this._.cache.nativeSel = {};
@@ -1154,6 +1462,13 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			this.document.setCustomData( 'cke_locked_selection', this );
 		},
 
+		/**
+		 * Unlocks the selection made in the editor and locked with the <code>#lock</code> method.
+		 * An unlocked selection is no longer cached and can be changed.
+		 * @param {Boolean} [restore] If set to <code>true</code>, the selection is restored back to the selection saved earlier by using the <code>#lock</code> method.
+		 * @example
+		 * editor.getSelection().<strong>unlock()</strong>;
+		 */
 		unlock : function( restore )
 		{
 			var doc = this.document,
@@ -1171,8 +1486,6 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 					this.isLocked = 0;
 					this.reset();
 
-					doc.getBody().focus();
-
 					if ( selectedElement )
 						this.selectElement( selectedElement );
 					else
@@ -1187,14 +1500,22 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			}
 		},
 
+		/**
+		 * Clears the selection cache.
+		 * @example
+		 * editor.getSelection().<strong>reset()</strong>;
+		 */
 		reset : function()
 		{
 			this._.cache = {};
 		},
 
 		/**
-		 *  Make the current selection of type {@link CKEDITOR.SELECTION_ELEMENT} by enclosing the specified element.
-		 * @param element
+		 * Makes the current selection of type <code>{@link CKEDITOR.SELECTION_ELEMENT}</code> by enclosing the specified element.
+		 * @param {CKEDITOR.dom.element} element The element to enclose in the selection.
+		 * @example
+		 * var element = editor.document.getById( 'sampleElement' );
+		 * editor.getSelection.<strong>selectElement( element )</strong>;
 		 */
 		selectElement : function( element )
 		{
@@ -1223,9 +1544,12 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 *  Adding the specified ranges to document selection preceding
-		 * by clearing up the original selection.
-		 * @param {CKEDITOR.dom.range} ranges
+		 *  Clears the original selection and adds the specified ranges
+		 * to the document selection.
+		 * @param {Array} ranges An array of <code>{@link CKEDITOR.dom.range}</code> instances representing ranges to be added to the document.
+		 * @example
+		 * var ranges = new CKEDITOR.dom.range( editor.document );
+		 * editor.getSelection().<strong>selectRanges( [ ranges ] )</strong>;
 		 */
 		selectRanges : function( ranges )
 		{
@@ -1364,15 +1688,20 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 					sel.addRange( nativeRange );
 				}
 
+				// Don't miss selection change event for non-IEs.
+				this.document.fire( 'selectionchange' );
 				this.reset();
 			}
 		},
 
 		/**
-		 *  Create bookmark for every single of this selection range (from #getRanges)
-		 * by calling the {@link CKEDITOR.dom.range.prototype.createBookmark} method,
-		 * with extra cares to avoid interferon among those ranges. Same arguments are
-		 * received as with the underlay range method.
+		 *  Creates a bookmark for each range of this selection (from <code>#getRanges</code>)
+		 * by calling the <code>{@link CKEDITOR.dom.range.prototype.createBookmark}</code> method,
+		 * with extra care taken to avoid interference among those ranges. The arguments
+		 * received are the same as with the underlying range method.
+		 * @returns {Array} Array of bookmarks for each range.
+		 * @example
+		 * var bookmarks = editor.getSelection().<strong>createBookmarks()</strong>;
 		 */
 		createBookmarks : function( serializable )
 		{
@@ -1380,10 +1709,13 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 *  Create bookmark for every single of this selection range (from #getRanges)
-		 * by calling the {@link CKEDITOR.dom.range.prototype.createBookmark2} method,
-		 * with extra cares to avoid interferon among those ranges. Same arguments are
-		 * received as with the underlay range method.
+		 *  Creates a bookmark for each range of this selection (from <code>#getRanges</code>)
+		 * by calling the <code>{@link CKEDITOR.dom.range.prototype.createBookmark2}</code> method,
+		 * with extra care taken to avoid interference among those ranges. The arguments
+		 * received are the same as with the underlying range method.
+		 * @returns {Array} Array of bookmarks for each range.
+		 * @example
+		 * var bookmarks = editor.getSelection().<strong>createBookmarks2()</strong>;
 		 */
 		createBookmarks2 : function( normalized )
 		{
@@ -1391,8 +1723,12 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 * Select the virtual ranges denote by the bookmarks by calling #selectRanges.
-		 * @param bookmarks
+		 * Selects the virtual ranges denoted by the bookmarks by calling <code>#selectRanges</code>.
+		 * @param {Array} bookmarks The bookmarks representing ranges to be selected.
+		 * @returns {CKEDITOR.dom.selection} This selection object, after the ranges were selected.
+		 * @example
+		 * var bookmarks = editor.getSelection().createBookmarks();
+		 * editor.getSelection().<strong>selectBookmarks( bookmarks )</strong>;
 		 */
 		selectBookmarks : function( bookmarks )
 		{
@@ -1408,7 +1744,10 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 * Retrieve the common ancestor node of the first range and the last range.
+		 * Retrieves the common ancestor node of the first range and the last range.
+		 * @returns {CKEDITOR.dom.element} The common ancestor of the selection.
+		 * @example
+		 * var ancestor = editor.getSelection().<strong>getCommonAncestor()</strong>;
 		 */
 		getCommonAncestor : function()
 		{
@@ -1419,7 +1758,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 		},
 
 		/**
-		 * Moving scroll bar to the current selection's start position.
+		 * Moves the scrollbar to the starting position of the current selection.
+		 * @example
+		 * editor.getSelection().<strong>scrollIntoView()</strong>;
 		 */
 		scrollIntoView : function()
 		{
@@ -1429,11 +1770,9 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 			start.scrollIntoView();
 		}
 	};
-})();
 
-( function()
-{
 	var notWhitespaces = CKEDITOR.dom.walker.whitespaces( true ),
+			isVisible = CKEDITOR.dom.walker.invisible( 1 ),
 			fillerTextRegex = /\ufeff|\u00a0/,
 			nonCells = { table:1,tbody:1,tr:1 };
 
